'use strict';

var react = require('react');
var useWeb3AuthInner = require('./useWeb3AuthInner.js');

const useManageMFA = () => {
  const {
    web3Auth
  } = useWeb3AuthInner.useWeb3AuthInner();
  const [loading, setLoading] = react.useState(false);
  const [error, setError] = react.useState(null);
  const manageMFA = react.useCallback(async params => {
    setLoading(true);
    setError(null);
    try {
      await web3Auth.manageMFA(params);
    } catch (error) {
      setError(error);
    } finally {
      setLoading(false);
    }
  }, [web3Auth]);
  return {
    loading,
    error,
    manageMFA
  };
};

exports.useManageMFA = useManageMFA;
