'use strict';

var react = require('react');
var useWeb3AuthInner = require('./useWeb3AuthInner.js');

const useSwitchChain = () => {
  const {
    web3Auth
  } = useWeb3AuthInner.useWeb3AuthInner();
  const [loading, setLoading] = react.useState(false);
  const [error, setError] = react.useState(null);
  const switchChain = react.useCallback(async chainId => {
    setLoading(true);
    setError(null);
    try {
      await web3Auth.switchChain({
        chainId
      });
    } catch (error) {
      setError(error);
    } finally {
      setLoading(false);
    }
  }, [web3Auth]);
  return {
    loading,
    error,
    switchChain
  };
};

exports.useSwitchChain = useSwitchChain;
