'use strict';

var noModal = require('@web3auth/no-modal');
var react = require('react');
var useWalletServicesPlugin = require('./useWalletServicesPlugin.js');

const useWalletConnectScanner = () => {
  const {
    plugin,
    ready
  } = useWalletServicesPlugin.useWalletServicesPlugin();
  const [loading, setLoading] = react.useState(false);
  const [error, setError] = react.useState(null);
  const showWalletConnectScanner = react.useCallback(async showWalletConnectScannerParams => {
    setLoading(true);
    setError(null);
    try {
      if (!plugin) throw noModal.WalletServicesPluginError.notInitialized();
      if (!ready) throw noModal.WalletServicesPluginError.walletPluginNotConnected();
      await plugin.showWalletConnectScanner(showWalletConnectScannerParams);
    } catch (error) {
      setError(error);
    } finally {
      setLoading(false);
    }
  }, [plugin, ready]);
  return {
    loading,
    error,
    showWalletConnectScanner
  };
};

exports.useWalletConnectScanner = useWalletConnectScanner;
