'use strict';

var react = require('react');
var useWeb3AuthInner = require('./useWeb3AuthInner.js');

const useWeb3AuthDisconnect = () => {
  const {
    web3Auth
  } = useWeb3AuthInner.useWeb3AuthInner();
  const [loading, setLoading] = react.useState(false);
  const [error, setError] = react.useState(null);
  const disconnect = react.useCallback(async options => {
    setLoading(true);
    setError(null);
    try {
      await web3Auth.logout(options);
    } catch (error) {
      setError(error);
    } finally {
      setLoading(false);
    }
  }, [web3Auth]);
  return {
    loading,
    error,
    disconnect
  };
};

exports.useWeb3AuthDisconnect = useWeb3AuthDisconnect;
