'use strict';

var noModal = require('@web3auth/no-modal');
var react = require('react');
var useSolanaWallet = require('./useSolanaWallet.js');

const useSignTransaction = () => {
  const {
    solanaWallet
  } = useSolanaWallet.useSolanaWallet();
  const [loading, setLoading] = react.useState(false);
  const [error, setError] = react.useState(null);
  const [data, setData] = react.useState(null);
  const signTransaction = react.useCallback(async transaction => {
    setLoading(true);
    setError(null);
    try {
      if (!solanaWallet) throw noModal.WalletInitializationError.notReady();
      const signedTransaction = await solanaWallet.signTransaction(transaction);
      setData(signedTransaction);
      return signedTransaction;
    } catch (error) {
      setError(error);
    } finally {
      setLoading(false);
    }
  }, [solanaWallet]);
  return {
    loading,
    error,
    data,
    signTransaction
  };
};

exports.useSignTransaction = useSignTransaction;
