'use strict';

var noModal = require('@web3auth/no-modal');
var vue = require('vue');
var useWeb3AuthInner = require('./useWeb3AuthInner.js');

const useIdentityToken = () => {
  const {
    web3Auth,
    isConnected
  } = useWeb3AuthInner.useWeb3AuthInner();
  const loading = vue.ref(false);
  const error = vue.ref(null);
  const token = vue.ref(null);
  const getIdentityToken = async () => {
    try {
      if (!web3Auth.value) throw noModal.WalletInitializationError.notReady();
      error.value = null;
      loading.value = true;
      const result = await web3Auth.value.getIdentityToken();
      if (result !== null && result !== void 0 && result.idToken) {
        token.value = result.idToken;
      }
      return result === null || result === void 0 ? void 0 : result.idToken;
    } catch (err) {
      error.value = err;
    } finally {
      loading.value = false;
    }
  };
  vue.watch(isConnected, newIsConnected => {
    if (!newIsConnected && token.value) {
      token.value = null;
    }
  });
  return {
    loading,
    error,
    token,
    getIdentityToken
  };
};

exports.useIdentityToken = useIdentityToken;
