'use strict';

var noModal = require('@web3auth/no-modal');
var vue = require('vue');
var useSolanaWallet = require('./useSolanaWallet.js');

const useSignAndSendTransaction = () => {
  const {
    solanaWallet
  } = useSolanaWallet.useSolanaWallet();
  const loading = vue.ref(false);
  const error = vue.ref(null);
  const data = vue.ref(null);
  const signAndSendTransaction = async transaction => {
    loading.value = true;
    error.value = null;
    try {
      if (!solanaWallet.value) throw noModal.WalletInitializationError.notReady();
      const signature = await solanaWallet.value.signAndSendTransaction(transaction);
      data.value = signature;
      return signature;
    } catch (err) {
      error.value = err;
    } finally {
      loading.value = false;
    }
  };
  return {
    loading,
    error,
    data,
    signAndSendTransaction
  };
};

exports.useSignAndSendTransaction = useSignAndSendTransaction;
