'use strict';

var noModal = require('@web3auth/no-modal');
var vue = require('vue');
var useSolanaWallet = require('./useSolanaWallet.js');

const useSignTransaction = () => {
  const {
    solanaWallet
  } = useSolanaWallet.useSolanaWallet();
  const loading = vue.ref(false);
  const error = vue.ref(null);
  const data = vue.ref(null);
  const signTransaction = async transaction => {
    loading.value = true;
    error.value = null;
    try {
      if (!solanaWallet.value) throw noModal.WalletInitializationError.notReady();
      const signedTransaction = await solanaWallet.value.signTransaction(transaction);
      data.value = signedTransaction;
      return signedTransaction;
    } catch (err) {
      error.value = err;
    } finally {
      loading.value = false;
    }
  };
  return {
    loading,
    error,
    data,
    signTransaction
  };
};

exports.useSignTransaction = useSignTransaction;
