import { useState, useCallback } from 'react';
import { useWeb3AuthInner } from './useWeb3AuthInner.js';

const useEnableMFA = () => {
  const {
    web3Auth
  } = useWeb3AuthInner();
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);
  const enableMFA = useCallback(async params => {
    setLoading(true);
    setError(null);
    try {
      await web3Auth.enableMFA(params);
    } catch (error) {
      setError(error);
    } finally {
      setLoading(false);
    }
  }, [web3Auth]);
  return {
    loading,
    error,
    enableMFA
  };
};

export { useEnableMFA };
