import { useState, useCallback } from 'react';
import { useWeb3AuthInner } from './useWeb3AuthInner.js';

const useSwitchChain = () => {
  const {
    web3Auth
  } = useWeb3AuthInner();
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);
  const switchChain = useCallback(async chainId => {
    setLoading(true);
    setError(null);
    try {
      await web3Auth.switchChain({
        chainId
      });
    } catch (error) {
      setError(error);
    } finally {
      setLoading(false);
    }
  }, [web3Auth]);
  return {
    loading,
    error,
    switchChain
  };
};

export { useSwitchChain };
