import { AUTH_CONNECTION } from '@web3auth/auth';
import { WalletInitializationError } from '@web3auth/no-modal';
import EmailPasswordlessHandler from './EmailPasswordlessHandler.js';
import SmsPasswordlessHandler from './SmsPasswordlessHandler.js';

const createPasswordlessHandler = (authConnection, params) => {
  switch (authConnection) {
    case AUTH_CONNECTION.EMAIL_PASSWORDLESS:
      return new EmailPasswordlessHandler(params);
    case AUTH_CONNECTION.SMS_PASSWORDLESS:
      return new SmsPasswordlessHandler(params);
    default:
      throw WalletInitializationError.invalidParams(`Unsupported auth connection: ${authConnection}`);
  }
};

export { createPasswordlessHandler };
