import { WalletInitializationError } from '@web3auth/no-modal';
import { ref } from 'vue';
import { useWeb3AuthInner } from './useWeb3AuthInner.js';

const useEnableMFA = () => {
  const {
    web3Auth
  } = useWeb3AuthInner();
  const loading = ref(false);
  const error = ref(null);
  const enableMFA = async () => {
    try {
      if (!web3Auth.value) throw WalletInitializationError.notReady();
      error.value = null;
      loading.value = true;
      await web3Auth.value.enableMFA();
    } catch (err) {
      error.value = err;
    } finally {
      loading.value = false;
    }
  };
  return {
    loading,
    error,
    enableMFA
  };
};

export { useEnableMFA };
