import { WalletServicesPluginError } from '@web3auth/no-modal';
import { ref } from 'vue';
import { useWalletServicesPlugin } from './useWalletServicesPlugin.js';

const useSwap = () => {
  const {
    plugin,
    ready
  } = useWalletServicesPlugin();
  const loading = ref(false);
  const error = ref(null);
  const showSwap = async showSwapParams => {
    loading.value = true;
    error.value = null;
    try {
      if (!plugin) throw WalletServicesPluginError.notInitialized();
      if (!ready) throw WalletServicesPluginError.walletPluginNotConnected();
      await plugin.value.showSwap(showSwapParams);
    } catch (err) {
      error.value = err;
    } finally {
      loading.value = false;
    }
  };
  return {
    loading,
    error,
    showSwap
  };
};

export { useSwap };
