import { WalletInitializationError } from '@web3auth/no-modal';
import { ref } from 'vue';
import { useSolanaWallet } from './useSolanaWallet.js';

const useSignAndSendTransaction = () => {
  const {
    solanaWallet
  } = useSolanaWallet();
  const loading = ref(false);
  const error = ref(null);
  const data = ref(null);
  const signAndSendTransaction = async transaction => {
    loading.value = true;
    error.value = null;
    try {
      if (!solanaWallet.value) throw WalletInitializationError.notReady();
      const signature = await solanaWallet.value.signAndSendTransaction(transaction);
      data.value = signature;
      return signature;
    } catch (err) {
      error.value = err;
    } finally {
      loading.value = false;
    }
  };
  return {
    loading,
    error,
    data,
    signAndSendTransaction
  };
};

export { useSignAndSendTransaction };
